@@ -19,8 +19,8 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-from typing import Type, Union
 import os; import random; import string
+from typing import Type, Union
 from .crawler import Crawler
 
 class FileModder:
@@ -91,25 +91,35 @@ class FileModder:
 	@classmethod
 	def add_tag(self, filepath: str, tag: str, oldtags: list = [],
 				newtags: list = [], spliton: str = '-') -> str:
-		extension = Crawler.get_extension(filepath)
-		prefix = Crawler.get_prefix(filepath)
+		newtags_complete = [spliton + t for t in newtags]
+		oldtags_complete = [spliton + t for t in oldtags]
 
-		existing_tag = prefix.split(spliton)[-1]
+		rootdir = Crawler.get_rootdir(filepath)
+		prefix = Crawler.get_prefix(filepath)
+		extension = Crawler.get_extension(filepath)
+
+		existing_tag = spliton + prefix.split(spliton)[-1]
 
 		# If tag already applied then do not apply tag.
-		if existing_tag in newtags: return filepath
+		if existing_tag in newtags_complete:
+			return filepath
 
-		if existing_tag in oldtags:
+		if existing_tag in oldtags_complete:
 			#If existing tag is in old tags, then update it to tag.
-			return prefix.split(existing_tag)[0] + tag + extension
+			filename = prefix.split(existing_tag)[0] + spliton + tag + extension
+			return Crawler.joinpath(rootdir, filename)
 		else:
-			return prefix + spliton + tag + extension
+			filename = prefix + spliton + tag + extension
+			return Crawler.joinpath(rootdir, filename)
 
 	@classmethod
 	def add_rtag(self, filepath: str, length: int = 5, spliton: str = '-') -> str:
+		"""Adding a randomized tag."""
 		if length < 4: length = 4
 		if length > 10: length = 10
-		extension = Crawler.get_extension(filepath)
+		rootdir = Crawler.get_rootdir(filepath)
 		prefix = Crawler.get_prefix(filepath)
+		extension = Crawler.get_extension(filepath)
 		rtag=''.join(random.choices(string.ascii_uppercase + string.digits, k=length))
-		return prefix + spliton + rtag + extension
+		filename = prefix + spliton + rtag + extension
+		return Crawler.joinpath(rootdir, filename)
